@@ -10,14 +10,20 @@ sub _do_stroke { }
 
 sub _draw_arc { }
 
+sub _draw_bezier { }
+
 sub _draw_canvas { }
 
+sub _draw_circle { }
+
 sub _draw_component {
     my ($self, $comp) = @_;
 
     $self->{DATA} = "Mock: ".$comp->width."x".$comp->height;
 }
 
+sub _draw_ellipse { }
+
 sub _draw_line { }
 
 sub _draw_path { }
@@ -32,7 +38,7 @@ sub _finish_page { }
 
 sub _resize { }
 
-sub get_text_bounding_box { }
+sub get_textbox_layout { }
 
 sub reset { }
 
